@@ -82,7 +82,7 @@ def plot_graph_coords(vcoords, ecoords, plotpath, ax, shppath):
     plt.savefig(plotpath)
 
 ##########################################################
-def plot_graph(gin, plotpath='/tmp/mygraph.png', ax='', shppath=''):
+def plot_graph(gin, plotpath='/tmp/mygraph.png', inverty=False, ax='', shppath=''):
     """Plot the graph @gin which can be an igraph object or a graphml file path. If @shppath is provided, plot the border given by @shppath """
 
     import igraph
@@ -93,6 +93,9 @@ def plot_graph(gin, plotpath='/tmp/mygraph.png', ax='', shppath=''):
         if attrs[0] in g.vertex_attributes():
             xattr = 'x'; yattr = 'y'
 
+    if inverty:
+        g.vs[yattr] = - g.vs[yattr]
+
     vcoords = np.array([(x, y) for x, y in zip(g.vs[xattr], g.vs[yattr])])
     vcoords = vcoords.astype(float)
 
